.. _changelog:

**************
Full Changelog
**************

.. include:: latest_changelog.txt
.. include:: ../../CHANGELOG.rst


.. changelog::
   :towncrier: ../../
   :towncrier-skip-if-empty:
   :changelog_file: ../../CHANGELOG.rst
